==> charsay-0.1.0.tar.gz: charsay-0.1.0/README.md <==
# Charsay

**Character Say** - A simple Python package that generates ASCII art of characters saying a given string. Currently, it supports Simpsons characters, with more to be added in the future.

## Features

- **Simpsons Characters**: Supports Bart, Homer, Marge, Lisa, and Maggie.
- **Customizable Text**: Add your own text (up to 100 characters) for the characters to say.
- **ASCII Art**: Each character is represented in ASCII art form, inspired by existing Simpsons designs.

## Installation

To install this package, you can clone the repository and run it locally. Once published, it will be available on PyPI.

## Usage

Here's a basic example of how to use the package:

from charsay import bart, homer, marge, lisa, maggie

Example usage
bart("Eat my shorts!")
homer("D'oh!")
marge("Mmm... donuts!")
lisa("Saxophone solo!")
maggie("Ga ga ga!")


## Available Functions

- **bart(inp)**: Prints Bart Simpson saying the given text.
- **homer(inp)**: Prints Homer Simpson saying the given text.
- **marge(inp)**: Prints Marge Simpson saying the given text.
- **lisa(inp)**: Prints Lisa Simpson saying the given text.
- **maggie(inp)**: Prints Maggie Simpson saying the given text.

## Future Plans

- **More Characters**: Additional characters from other franchises will be added.
- **Text Length Limitation**: The text length limit may be increased in future updates.

## Contributing

Contributions are welcome! Feel free to add more characters or improve existing ones.

## License

This project is licensed under the [MIT License](LICENSE).

## Acknowledgments

- The Simpsons characters are copyrighted by Disney. This project uses ASCII art designs inspired by these characters for   non-commercial purposes.
- ASCII art designs are not original and are based on existing Simpsons designs.

## Legal Note

Please be aware that using Simpsons characters without permission may infringe on Disney's copyright. This project is intended for personal, non-commercial use. If you plan to use this project commercially, you should seek permission from Disney or ensure your use falls under fair use provisions.

==> charsay-0.1.2.tar.gz: charsay-0.1.2/README.md <==
# Charsay

**Character Say** - A simple Python package that generates ASCII art of characters saying a given string. Currently, it supports Simpsons characters, with more to be added in the future.

## Features

- **Simpsons Characters**: Supports Bart, Homer, Marge, Lisa, and Maggie.
- **Customizable Text**: Add your own text for the characters to say.
- **ASCII Art**: Each character is represented in ASCII art form, inspired by existing Simpsons designs.

## Installation

To install this package, you can clone the repository and run it locally. Or it can be installed using pip from PyPI.


## Usage

Here's a basic example of how to use the package:

#### Example usage:

`from charsay import bart, homer, marge, lisa, maggie` 

`bart("Eat my shorts!")`
`homer("D'oh!")`
`marge("Mmm... donuts!")`
`lisa("Saxophone solo!")`
`maggie("Ga ga ga!")` 


## Available Functions

- **bart(inp)**: Prints Bart Simpson saying the given text.
- **homer(inp)**: Prints Homer Simpson saying the given text.
- **marge(inp)**: Prints Marge Simpson saying the given text.
- **lisa(inp)**: Prints Lisa Simpson saying the given text.
- **maggie(inp)**: Prints Maggie Simpson saying the given text.

## Contributing

Contributions are welcome! Feel free to add more characters or improve existing ones.

## License

This project is licensed under the [MIT License](LICENSE).

## Acknowledgments

- The Simpsons characters are copyrighted by Disney. This project uses ASCII art designs inspired by these characters for non-commercial purposes.
- ASCII art designs are not original and are based on existing Simpsons designs.

## Legal Note

Please be aware that using Simpsons characters without permission may infringe on Disney's copyright. This project is intended for personal, non-commercial use. If you plan to use this project commercially, you should seek permission from Disney or ensure your use falls under fair use provisions.
